# This file is part of PyCm, a Python interface to the Cm library
#
# Copyright (C) 2020-2021  European Gravitational Observatory
#
# Author list: Franco Carbognani: franco.carbognani@ego-gw.it
#                   Rhys Poulton: poulton@ego-gw.it
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
r"""Wrapper for CmMessage.h

Generated with:
/users/poulton/.local/bin/ctypesgen -a -l libpycm.so --compile-libdir /virgoDev/PyCm/v7r4/Linux-x86_64-CL7-cmake/src/ -I /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/ -I /virgoDev/PyCm/v7r4/src/ /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h /virgoDev/PyCm/v7r4/src/Handlers.h -o PyCm/PyCm.py

Do not modify this file.
"""

__docformat__ = "restructuredtext"

# Begin preamble for Python v(3, 2)

import ctypes, os, sys
from ctypes import *

class c_void(Structure):
    # c_void_p is a buggy return type, converting to int, so
    # POINTER(None) == c_void_p is actually written as
    # POINTER(c_void), so it can be treated as a real pointer.
    _fields_ = [("dummy", c_int)]

def POINTER(obj):
    p = ctypes.POINTER(obj)

    # Convert None to a real NULL pointer to work around bugs
    # in how ctypes handles None on 64-bit platforms
    if not isinstance(p.from_param, classmethod):

        def from_param(cls, x):
            if x is None:
                return cls()
            else:
                return x

        p.from_param = classmethod(from_param)

    return p

_int_types = (c_int16, c_int32)
if hasattr(ctypes, "c_int64"):
    # Some builds of ctypes apparently do not have c_int64
    # defined; it's a pretty good bet that these builds do not
    # have 64-bit pointers.
    _int_types += (c_int64,)
for t in _int_types:
    if sizeof(t) == sizeof(c_size_t):
        c_ptrdiff_t = t
del t
del _int_types


class UserString:
    def __init__(self, seq):
        if isinstance(seq, bytes):
            self.data = seq
        elif isinstance(seq, UserString):
            self.data = seq.data[:]
        else:
            self.data = str(seq).encode()

    def __bytes__(self):
        return self.data

    def __str__(self):
        return self.data.decode()

    def __repr__(self):
        return repr(self.data)

    def __int__(self):
        return int(self.data.decode())

    def __long__(self):
        return int(self.data.decode())

    def __float__(self):
        return float(self.data.decode())

    def __complex__(self):
        return complex(self.data.decode())

    def __hash__(self):
        return hash(self.data)

    def __cmp__(self, string):
        if isinstance(string, UserString):
            return cmp(self.data, string.data)
        else:
            return cmp(self.data, string)

    def __le__(self, string):
        if isinstance(string, UserString):
            return self.data <= string.data
        else:
            return self.data <= string

    def __lt__(self, string):
        if isinstance(string, UserString):
            return self.data < string.data
        else:
            return self.data < string

    def __ge__(self, string):
        if isinstance(string, UserString):
            return self.data >= string.data
        else:
            return self.data >= string

    def __gt__(self, string):
        if isinstance(string, UserString):
            return self.data > string.data
        else:
            return self.data > string

    def __eq__(self, string):
        if isinstance(string, UserString):
            return self.data == string.data
        else:
            return self.data == string

    def __ne__(self, string):
        if isinstance(string, UserString):
            return self.data != string.data
        else:
            return self.data != string

    def __contains__(self, char):
        return char in self.data

    def __len__(self):
        return len(self.data)

    def __getitem__(self, index):
        return self.__class__(self.data[index])

    def __getslice__(self, start, end):
        start = max(start, 0)
        end = max(end, 0)
        return self.__class__(self.data[start:end])

    def __add__(self, other):
        if isinstance(other, UserString):
            return self.__class__(self.data + other.data)
        elif isinstance(other, bytes):
            return self.__class__(self.data + other)
        else:
            return self.__class__(self.data + str(other).encode())

    def __radd__(self, other):
        if isinstance(other, bytes):
            return self.__class__(other + self.data)
        else:
            return self.__class__(str(other).encode() + self.data)

    def __mul__(self, n):
        return self.__class__(self.data * n)

    __rmul__ = __mul__

    def __mod__(self, args):
        return self.__class__(self.data % args)

    # the following methods are defined in alphabetical order:
    def capitalize(self):
        return self.__class__(self.data.capitalize())

    def center(self, width, *args):
        return self.__class__(self.data.center(width, *args))

    def count(self, sub, start=0, end=sys.maxsize):
        return self.data.count(sub, start, end)

    def decode(self, encoding=None, errors=None):  # XXX improve this?
        if encoding:
            if errors:
                return self.__class__(self.data.decode(encoding, errors))
            else:
                return self.__class__(self.data.decode(encoding))
        else:
            return self.__class__(self.data.decode())

    def encode(self, encoding=None, errors=None):  # XXX improve this?
        if encoding:
            if errors:
                return self.__class__(self.data.encode(encoding, errors))
            else:
                return self.__class__(self.data.encode(encoding))
        else:
            return self.__class__(self.data.encode())

    def endswith(self, suffix, start=0, end=sys.maxsize):
        return self.data.endswith(suffix, start, end)

    def expandtabs(self, tabsize=8):
        return self.__class__(self.data.expandtabs(tabsize))

    def find(self, sub, start=0, end=sys.maxsize):
        return self.data.find(sub, start, end)

    def index(self, sub, start=0, end=sys.maxsize):
        return self.data.index(sub, start, end)

    def isalpha(self):
        return self.data.isalpha()

    def isalnum(self):
        return self.data.isalnum()

    def isdecimal(self):
        return self.data.isdecimal()

    def isdigit(self):
        return self.data.isdigit()

    def islower(self):
        return self.data.islower()

    def isnumeric(self):
        return self.data.isnumeric()

    def isspace(self):
        return self.data.isspace()

    def istitle(self):
        return self.data.istitle()

    def isupper(self):
        return self.data.isupper()

    def join(self, seq):
        return self.data.join(seq)

    def ljust(self, width, *args):
        return self.__class__(self.data.ljust(width, *args))

    def lower(self):
        return self.__class__(self.data.lower())

    def lstrip(self, chars=None):
        return self.__class__(self.data.lstrip(chars))

    def partition(self, sep):
        return self.data.partition(sep)

    def replace(self, old, new, maxsplit=-1):
        return self.__class__(self.data.replace(old, new, maxsplit))

    def rfind(self, sub, start=0, end=sys.maxsize):
        return self.data.rfind(sub, start, end)

    def rindex(self, sub, start=0, end=sys.maxsize):
        return self.data.rindex(sub, start, end)

    def rjust(self, width, *args):
        return self.__class__(self.data.rjust(width, *args))

    def rpartition(self, sep):
        return self.data.rpartition(sep)

    def rstrip(self, chars=None):
        return self.__class__(self.data.rstrip(chars))

    def split(self, sep=None, maxsplit=-1):
        return self.data.split(sep, maxsplit)

    def rsplit(self, sep=None, maxsplit=-1):
        return self.data.rsplit(sep, maxsplit)

    def splitlines(self, keepends=0):
        return self.data.splitlines(keepends)

    def startswith(self, prefix, start=0, end=sys.maxsize):
        return self.data.startswith(prefix, start, end)

    def strip(self, chars=None):
        return self.__class__(self.data.strip(chars))

    def swapcase(self):
        return self.__class__(self.data.swapcase())

    def title(self):
        return self.__class__(self.data.title())

    def translate(self, *args):
        return self.__class__(self.data.translate(*args))

    def upper(self):
        return self.__class__(self.data.upper())

    def zfill(self, width):
        return self.__class__(self.data.zfill(width))


class MutableString(UserString):
    """mutable string objects

    Python strings are immutable objects.  This has the advantage, that
    strings may be used as dictionary keys.  If this property isn't needed
    and you insist on changing string values in place instead, you may cheat
    and use MutableString.

    But the purpose of this class is an educational one: to prevent
    people from inventing their own mutable string class derived
    from UserString and than forget thereby to remove (override) the
    __hash__ method inherited from UserString.  This would lead to
    errors that would be very hard to track down.

    A faster and better solution is to rewrite your program using lists."""

    def __init__(self, string=""):
        self.data = string

    def __hash__(self):
        raise TypeError("unhashable type (it is mutable)")

    def __setitem__(self, index, sub):
        if index < 0:
            index += len(self.data)
        if index < 0 or index >= len(self.data):
            raise IndexError
        self.data = self.data[:index] + sub + self.data[index + 1 :]

    def __delitem__(self, index):
        if index < 0:
            index += len(self.data)
        if index < 0 or index >= len(self.data):
            raise IndexError
        self.data = self.data[:index] + self.data[index + 1 :]

    def __setslice__(self, start, end, sub):
        start = max(start, 0)
        end = max(end, 0)
        if isinstance(sub, UserString):
            self.data = self.data[:start] + sub.data + self.data[end:]
        elif isinstance(sub, bytes):
            self.data = self.data[:start] + sub + self.data[end:]
        else:
            self.data = self.data[:start] + str(sub).encode() + self.data[end:]

    def __delslice__(self, start, end):
        start = max(start, 0)
        end = max(end, 0)
        self.data = self.data[:start] + self.data[end:]

    def immutable(self):
        return UserString(self.data)

    def __iadd__(self, other):
        if isinstance(other, UserString):
            self.data += other.data
        elif isinstance(other, bytes):
            self.data += other
        else:
            self.data += str(other).encode()
        return self

    def __imul__(self, n):
        self.data *= n
        return self


class String(MutableString, Union):

    _fields_ = [("raw", POINTER(c_char)), ("data", c_char_p)]

    def __init__(self, obj=""):
        if isinstance(obj, (bytes, UserString)):
            self.data = bytes(obj)
        else:
            self.raw = obj

    def __len__(self):
        return self.data and len(self.data) or 0

    def from_param(cls, obj):
        # Convert None or 0
        if obj is None or obj == 0:
            return cls(POINTER(c_char)())

        # Convert from String
        elif isinstance(obj, String):
            return obj

        # Convert from bytes
        elif isinstance(obj, bytes):
            return cls(obj)

        # Convert from str
        elif isinstance(obj, str):
            return cls(obj.encode())

        # Convert from c_char_p
        elif isinstance(obj, c_char_p):
            return obj

        # Convert from POINTER(c_char)
        elif isinstance(obj, POINTER(c_char)):
            return obj

        # Convert from raw pointer
        elif isinstance(obj, int):
            return cls(cast(obj, POINTER(c_char)))

        # Convert from c_char array
        elif isinstance(obj, c_char * len(obj)):
            return obj

        # Convert from object
        else:
            return String.from_param(obj._as_parameter_)

    from_param = classmethod(from_param)


def ReturnString(obj, func=None, arguments=None):
    return String.from_param(obj)


# As of ctypes 1.0, ctypes does not support custom error-checking
# functions on callbacks, nor does it support custom datatypes on
# callbacks, so we must ensure that all callbacks return
# primitive datatypes.
#
# Non-primitive return values wrapped with UNCHECKED won't be
# typechecked, and will be converted to c_void_p.
def UNCHECKED(type):
    if hasattr(type, "_type_") and isinstance(type._type_, str) and type._type_ != "P":
        return type
    else:
        return c_void_p


# ctypes doesn't have direct support for variadic functions, so we have to write
# our own wrapper class
class _variadic_function(object):
    def __init__(self, func, restype, argtypes, errcheck):
        self.func = func
        self.func.restype = restype
        self.argtypes = argtypes
        if errcheck:
            self.func.errcheck = errcheck

    def _as_parameter_(self):
        # So we can pass this variadic function as a function pointer
        return self.func

    def __call__(self, *args):
        fixed_args = []
        i = 0
        for argtype in self.argtypes:
            # Typecheck what we can
            fixed_args.append(argtype.from_param(args[i]))
            i += 1
        return self.func(*fixed_args + list(args[i:]))


def ord_if_char(value):
    """
    Simple helper used for casts to simple builtin types:  if the argument is a
    string type, it will be converted to it's ordinal value.

    This function will raise an exception if the argument is string with more
    than one characters.
    """
    return ord(value) if (isinstance(value, bytes) or isinstance(value, str)) else value

# End preamble

_libs = {}
_libdirs = ['/virgoDev/PyCm/v7r4/Linux-x86_64-CL7-cmake/src/']

# Begin loader

# ----------------------------------------------------------------------------
# Copyright (c) 2008 David James
# Copyright (c) 2006-2008 Alex Holkner
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of pyglet nor the names of its
#    contributors may be used to endorse or promote products
#    derived from this software without specific prior written
#    permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
# ----------------------------------------------------------------------------

import os.path, re, sys, glob
import platform
import ctypes
import ctypes.util


def _environ_path(name):
    if name in os.environ:
        return os.environ[name].split(":")
    else:
        return []


class LibraryLoader(object):
    # library names formatted specifically for platforms
    name_formats = ["%s"]

    class Lookup(object):
        mode = ctypes.DEFAULT_MODE

        def __init__(self, path):
            super(LibraryLoader.Lookup, self).__init__()
            self.access = dict(cdecl=ctypes.CDLL(path, self.mode))

        def get(self, name, calling_convention="cdecl"):
            if calling_convention not in self.access:
                raise LookupError(
                    "Unknown calling convention '{}' for function '{}'".format(
                        calling_convention, name
                    )
                )
            return getattr(self.access[calling_convention], name)

        def has(self, name, calling_convention="cdecl"):
            if calling_convention not in self.access:
                return False
            return hasattr(self.access[calling_convention], name)

        def __getattr__(self, name):
            return getattr(self.access["cdecl"], name)

    def __init__(self):
        self.other_dirs = []

    def __call__(self, libname):
        """Given the name of a library, load it."""
        paths = self.getpaths(libname)

        for path in paths:
            try:
                return self.Lookup(path)
            except:
                pass

        raise ImportError("Could not load %s." % libname)

    def getpaths(self, libname):
        """Return a list of paths where the library might be found."""
        if os.path.isabs(libname):
            yield libname
        else:
            # search through a prioritized series of locations for the library

            # we first search any specific directories identified by user
            for dir_i in self.other_dirs:
                for fmt in self.name_formats:
                    # dir_i should be absolute already
                    yield os.path.join(dir_i, fmt % libname)

            # then we search the directory where the generated python interface is stored
            for fmt in self.name_formats:
                yield os.path.abspath(os.path.join(os.path.dirname(__file__), fmt % libname))

            # now, use the ctypes tools to try to find the library
            for fmt in self.name_formats:
                path = ctypes.util.find_library(fmt % libname)
                if path:
                    yield path

            # then we search all paths identified as platform-specific lib paths
            for path in self.getplatformpaths(libname):
                yield path

            # Finally, we'll try the users current working directory
            for fmt in self.name_formats:
                yield os.path.abspath(os.path.join(os.path.curdir, fmt % libname))

    def getplatformpaths(self, libname):
        return []


# Darwin (Mac OS X)


class DarwinLibraryLoader(LibraryLoader):
    name_formats = [
        "lib%s.dylib",
        "lib%s.so",
        "lib%s.bundle",
        "%s.dylib",
        "%s.so",
        "%s.bundle",
        "%s",
    ]

    class Lookup(LibraryLoader.Lookup):
        # Darwin requires dlopen to be called with mode RTLD_GLOBAL instead
        # of the default RTLD_LOCAL.  Without this, you end up with
        # libraries not being loadable, resulting in "Symbol not found"
        # errors
        mode = ctypes.RTLD_GLOBAL

    def getplatformpaths(self, libname):
        if os.path.pathsep in libname:
            names = [libname]
        else:
            names = [format % libname for format in self.name_formats]

        for dir in self.getdirs(libname):
            for name in names:
                yield os.path.join(dir, name)

    def getdirs(self, libname):
        """Implements the dylib search as specified in Apple documentation:

        http://developer.apple.com/documentation/DeveloperTools/Conceptual/
            DynamicLibraries/Articles/DynamicLibraryUsageGuidelines.html

        Before commencing the standard search, the method first checks
        the bundle's ``Frameworks`` directory if the application is running
        within a bundle (OS X .app).
        """

        dyld_fallback_library_path = _environ_path("DYLD_FALLBACK_LIBRARY_PATH")
        if not dyld_fallback_library_path:
            dyld_fallback_library_path = [os.path.expanduser("~/lib"), "/usr/local/lib", "/usr/lib"]

        dirs = []

        if "/" in libname:
            dirs.extend(_environ_path("DYLD_LIBRARY_PATH"))
        else:
            dirs.extend(_environ_path("LD_LIBRARY_PATH"))
            dirs.extend(_environ_path("DYLD_LIBRARY_PATH"))

        if hasattr(sys, "frozen") and sys.frozen == "macosx_app":
            dirs.append(os.path.join(os.environ["RESOURCEPATH"], "..", "Frameworks"))

        dirs.extend(dyld_fallback_library_path)

        return dirs


# Posix


class PosixLibraryLoader(LibraryLoader):
    _ld_so_cache = None

    _include = re.compile(r"^\s*include\s+(?P<pattern>.*)")

    class _Directories(dict):
        def __init__(self):
            self.order = 0

        def add(self, directory):
            if len(directory) > 1:
                directory = directory.rstrip(os.path.sep)
            # only adds and updates order if exists and not already in set
            if not os.path.exists(directory):
                return
            o = self.setdefault(directory, self.order)
            if o == self.order:
                self.order += 1

        def extend(self, directories):
            for d in directories:
                self.add(d)

        def ordered(self):
            return (i[0] for i in sorted(self.items(), key=lambda D: D[1]))

    def _get_ld_so_conf_dirs(self, conf, dirs):
        """
        Recursive funtion to help parse all ld.so.conf files, including proper
        handling of the `include` directive.
        """

        try:
            with open(conf) as f:
                for D in f:
                    D = D.strip()
                    if not D:
                        continue

                    m = self._include.match(D)
                    if not m:
                        dirs.add(D)
                    else:
                        for D2 in glob.glob(m.group("pattern")):
                            self._get_ld_so_conf_dirs(D2, dirs)
        except IOError:
            pass

    def _create_ld_so_cache(self):
        # Recreate search path followed by ld.so.  This is going to be
        # slow to build, and incorrect (ld.so uses ld.so.cache, which may
        # not be up-to-date).  Used only as fallback for distros without
        # /sbin/ldconfig.
        #
        # We assume the DT_RPATH and DT_RUNPATH binary sections are omitted.

        directories = self._Directories()
        for name in (
            "LD_LIBRARY_PATH",
            "SHLIB_PATH",  # HPUX
            "LIBPATH",  # OS/2, AIX
            "LIBRARY_PATH",  # BE/OS
        ):
            if name in os.environ:
                directories.extend(os.environ[name].split(os.pathsep))

        self._get_ld_so_conf_dirs("/etc/ld.so.conf", directories)

        bitage = platform.architecture()[0]

        unix_lib_dirs_list = []
        if bitage.startswith("64"):
            # prefer 64 bit if that is our arch
            unix_lib_dirs_list += ["/lib64", "/usr/lib64"]

        # must include standard libs, since those paths are also used by 64 bit
        # installs
        unix_lib_dirs_list += ["/lib", "/usr/lib"]
        if sys.platform.startswith("linux"):
            # Try and support multiarch work in Ubuntu
            # https://wiki.ubuntu.com/MultiarchSpec
            if bitage.startswith("32"):
                # Assume Intel/AMD x86 compat
                unix_lib_dirs_list += ["/lib/i386-linux-gnu", "/usr/lib/i386-linux-gnu"]
            elif bitage.startswith("64"):
                # Assume Intel/AMD x86 compat
                unix_lib_dirs_list += ["/lib/x86_64-linux-gnu", "/usr/lib/x86_64-linux-gnu"]
            else:
                # guess...
                unix_lib_dirs_list += glob.glob("/lib/*linux-gnu")
        directories.extend(unix_lib_dirs_list)

        cache = {}
        lib_re = re.compile(r"lib(.*)\.s[ol]")
        ext_re = re.compile(r"\.s[ol]$")
        for dir in directories.ordered():
            try:
                for path in glob.glob("%s/*.s[ol]*" % dir):
                    file = os.path.basename(path)

                    # Index by filename
                    cache_i = cache.setdefault(file, set())
                    cache_i.add(path)

                    # Index by library name
                    match = lib_re.match(file)
                    if match:
                        library = match.group(1)
                        cache_i = cache.setdefault(library, set())
                        cache_i.add(path)
            except OSError:
                pass

        self._ld_so_cache = cache

    def getplatformpaths(self, libname):
        if self._ld_so_cache is None:
            self._create_ld_so_cache()

        result = self._ld_so_cache.get(libname, set())
        for i in result:
            # we iterate through all found paths for library, since we may have
            # actually found multiple architectures or other library types that
            # may not load
            yield i


# Windows


class WindowsLibraryLoader(LibraryLoader):
    name_formats = ["%s.dll", "lib%s.dll", "%slib.dll", "%s"]

    class Lookup(LibraryLoader.Lookup):
        def __init__(self, path):
            super(WindowsLibraryLoader.Lookup, self).__init__(path)
            self.access["stdcall"] = ctypes.windll.LoadLibrary(path)


# Platform switching

# If your value of sys.platform does not appear in this dict, please contact
# the Ctypesgen maintainers.

loaderclass = {
    "darwin": DarwinLibraryLoader,
    "cygwin": WindowsLibraryLoader,
    "win32": WindowsLibraryLoader,
    "msys": WindowsLibraryLoader,
}

load_library = loaderclass.get(sys.platform, PosixLibraryLoader)()


def add_library_search_dirs(other_dirs):
    """
    Add libraries to search paths.
    If library paths are relative, convert them to absolute with respect to this
    file's directory
    """
    for F in other_dirs:
        if not os.path.isabs(F):
            F = os.path.abspath(F)
        load_library.other_dirs.append(F)


del loaderclass

# End loader

add_library_search_dirs(['/virgoDev/PyCm/v7r4/Linux-x86_64-CL7/lib/'])
# Begin libraries
_libs["libpycm.so"] = load_library("libpycm.so")

# 1 libraries
# End libraries

# No modules

NULL = None# <built-in>

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 38
class struct__CmMessageRec(Structure):
    pass

CmMessage = POINTER(struct__CmMessageRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 38

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 39
class struct__CmMessageIteratorRec(Structure):
    pass

CmMessageIterator = POINTER(struct__CmMessageIteratorRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 39

enum_anon_1 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 45

CmMessageOk = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 45

CmMessageBreak = (CmMessageOk + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 45

CmMessageStatus = enum_anon_1# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 45

enum_anon_2 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

CmMessageIsDead = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

CmMessageIsNotReady = (CmMessageIsDead + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

CmMessageIsNew = (CmMessageIsNotReady + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

CmMessageIsNotEmpty = (CmMessageIsNew + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

CmMessageIsClosed = (CmMessageIsNotEmpty + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

CmMessageIsSending = (CmMessageIsClosed + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

CmMessageState = enum_anon_2# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 55

enum_anon_3 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 64

CmMessageChar = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 64

CmMessageShort = (CmMessageChar + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 64

CmMessageInt = (CmMessageShort + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 64

CmMessageFloat = (CmMessageInt + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 64

CmMessageDouble = (CmMessageFloat + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 64

CmMessageArrayType = enum_anon_3# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 64

enum_anon_4 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemChar = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemShort = (CmMessageItemChar + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemInt = (CmMessageItemShort + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemLong = (CmMessageItemInt + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemFloat = (CmMessageItemLong + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemDouble = (CmMessageItemFloat + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemArray = (CmMessageItemDouble + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemText = (CmMessageItemArray + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemBytes = (CmMessageItemText + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemTail = (CmMessageItemBytes + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemUnknown = (CmMessageItemTail + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageItemType = enum_anon_4# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 79

CmMessageHandler = CFUNCTYPE(UNCHECKED(CmMessageStatus), CmMessage, String, String)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 81

CmMessageItem = c_char# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 85

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 36
class struct__GCReferenceRec(Structure):
    pass

GCReference = POINTER(struct__GCReferenceRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 36

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 37
class struct__GCClassRec(Structure):
    pass

GCClass = POINTER(struct__GCClassRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 37

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 38
class struct__GCObjectRec(Structure):
    pass

GCObject = POINTER(struct__GCObjectRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 38

GCDeleteMethod = CFUNCTYPE(UNCHECKED(None), POINTER(None))# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 40

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 42
if _libs["libpycm.so"].has("GCStartup", "cdecl"):
    GCStartup = _libs["libpycm.so"].get("GCStartup", "cdecl")
    GCStartup.argtypes = []
    GCStartup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 43
if _libs["libpycm.so"].has("GCReferenceCleanup", "cdecl"):
    GCReferenceCleanup = _libs["libpycm.so"].get("GCReferenceCleanup", "cdecl")
    GCReferenceCleanup.argtypes = []
    GCReferenceCleanup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 44
if _libs["libpycm.so"].has("GCClassNew", "cdecl"):
    GCClassNew = _libs["libpycm.so"].get("GCClassNew", "cdecl")
    GCClassNew.argtypes = [String, GCDeleteMethod]
    GCClassNew.restype = GCClass

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 45
if _libs["libpycm.so"].has("GCClassDelete", "cdecl"):
    GCClassDelete = _libs["libpycm.so"].get("GCClassDelete", "cdecl")
    GCClassDelete.argtypes = [GCClass]
    GCClassDelete.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 46
if _libs["libpycm.so"].has("GCObjectNew", "cdecl"):
    GCObjectNew = _libs["libpycm.so"].get("GCObjectNew", "cdecl")
    GCObjectNew.argtypes = [POINTER(None), GCClass]
    GCObjectNew.restype = GCObject

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 47
if _libs["libpycm.so"].has("GCReferenceSet", "cdecl"):
    GCReferenceSet = _libs["libpycm.so"].get("GCReferenceSet", "cdecl")
    GCReferenceSet.argtypes = [POINTER(POINTER(None)), POINTER(None), POINTER(None)]
    GCReferenceSet.restype = GCReference

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 48
if _libs["libpycm.so"].has("GCReferenceMove", "cdecl"):
    GCReferenceMove = _libs["libpycm.so"].get("GCReferenceMove", "cdecl")
    GCReferenceMove.argtypes = [POINTER(POINTER(None)), POINTER(POINTER(None))]
    GCReferenceMove.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 49
if _libs["libpycm.so"].has("GCDumpBase", "cdecl"):
    GCDumpBase = _libs["libpycm.so"].get("GCDumpBase", "cdecl")
    GCDumpBase.argtypes = []
    GCDumpBase.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 50
if _libs["libpycm.so"].has("GCCleanup", "cdecl"):
    GCCleanup = _libs["libpycm.so"].get("GCCleanup", "cdecl")
    GCCleanup.argtypes = []
    GCCleanup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 38
class struct__CArrayRec(Structure):
    pass

CArray = POINTER(struct__CArrayRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 38

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 39
class struct__CStackRec(Structure):
    pass

CStack = POINTER(struct__CStackRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 39

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 40
class struct__CQueueRec(Structure):
    pass

CQueue = POINTER(struct__CQueueRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 40

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 41
class struct__CLListRec(Structure):
    pass

CLList = POINTER(struct__CLListRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 41

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 42
class struct__CHasherRec(Structure):
    pass

CHasher = POINTER(struct__CHasherRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 42

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 43
class struct__CIteratorRec(Structure):
    pass

CIterator = POINTER(struct__CIteratorRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 43

CMethod = CFUNCTYPE(UNCHECKED(None), POINTER(None))# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 45

CValuator = CFUNCTYPE(UNCHECKED(POINTER(c_ubyte)), POINTER(None))# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 46

CCoder = CFUNCTYPE(UNCHECKED(c_int), POINTER(None))# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 47

CTester = CFUNCTYPE(UNCHECKED(c_int), POINTER(None), POINTER(None))# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 48

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 50
if _libs["libpycm.so"].has("CArrayStartup", "cdecl"):
    CArrayStartup = _libs["libpycm.so"].get("CArrayStartup", "cdecl")
    CArrayStartup.argtypes = []
    CArrayStartup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 51
if _libs["libpycm.so"].has("CArrayCleanup", "cdecl"):
    CArrayCleanup = _libs["libpycm.so"].get("CArrayCleanup", "cdecl")
    CArrayCleanup.argtypes = []
    CArrayCleanup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 52
if _libs["libpycm.so"].has("CArrayCheck", "cdecl"):
    CArrayCheck = _libs["libpycm.so"].get("CArrayCheck", "cdecl")
    CArrayCheck.argtypes = []
    CArrayCheck.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 53
if _libs["libpycm.so"].has("CArrayNew", "cdecl"):
    CArrayNew = _libs["libpycm.so"].get("CArrayNew", "cdecl")
    CArrayNew.argtypes = []
    CArrayNew.restype = CArray

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 54
if _libs["libpycm.so"].has("CArrayErase", "cdecl"):
    CArrayErase = _libs["libpycm.so"].get("CArrayErase", "cdecl")
    CArrayErase.argtypes = [CArray]
    CArrayErase.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 55
if _libs["libpycm.so"].has("CArrayCount", "cdecl"):
    CArrayCount = _libs["libpycm.so"].get("CArrayCount", "cdecl")
    CArrayCount.argtypes = [CArray]
    CArrayCount.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 56
if _libs["libpycm.so"].has("CArrayAdd", "cdecl"):
    CArrayAdd = _libs["libpycm.so"].get("CArrayAdd", "cdecl")
    CArrayAdd.argtypes = [CArray, POINTER(None)]
    CArrayAdd.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 57
if _libs["libpycm.so"].has("CArrayRemove", "cdecl"):
    CArrayRemove = _libs["libpycm.so"].get("CArrayRemove", "cdecl")
    CArrayRemove.argtypes = [CArray, POINTER(None)]
    CArrayRemove.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 58
if _libs["libpycm.so"].has("CArrayItem", "cdecl"):
    CArrayItem = _libs["libpycm.so"].get("CArrayItem", "cdecl")
    CArrayItem.argtypes = [CArray, CIterator]
    CArrayItem.restype = POINTER(c_ubyte)
    CArrayItem.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 59
if _libs["libpycm.so"].has("CArrayRemoveAt", "cdecl"):
    CArrayRemoveAt = _libs["libpycm.so"].get("CArrayRemoveAt", "cdecl")
    CArrayRemoveAt.argtypes = [CArray, c_int]
    CArrayRemoveAt.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 60
if _libs["libpycm.so"].has("CArrayItemAt", "cdecl"):
    CArrayItemAt = _libs["libpycm.so"].get("CArrayItemAt", "cdecl")
    CArrayItemAt.argtypes = [CArray, c_int]
    CArrayItemAt.restype = POINTER(c_ubyte)
    CArrayItemAt.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 61
if _libs["libpycm.so"].has("CArrayFind", "cdecl"):
    CArrayFind = _libs["libpycm.so"].get("CArrayFind", "cdecl")
    CArrayFind.argtypes = [CArray, POINTER(None)]
    CArrayFind.restype = POINTER(c_ubyte)
    CArrayFind.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 62
if _libs["libpycm.so"].has("CArrayGiveIterator", "cdecl"):
    CArrayGiveIterator = _libs["libpycm.so"].get("CArrayGiveIterator", "cdecl")
    CArrayGiveIterator.argtypes = [CArray]
    CArrayGiveIterator.restype = CIterator

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 63
if _libs["libpycm.so"].has("CArrayGiveBackwardIterator", "cdecl"):
    CArrayGiveBackwardIterator = _libs["libpycm.so"].get("CArrayGiveBackwardIterator", "cdecl")
    CArrayGiveBackwardIterator.argtypes = [CArray]
    CArrayGiveBackwardIterator.restype = CIterator

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 64
if _libs["libpycm.so"].has("CStackNew", "cdecl"):
    CStackNew = _libs["libpycm.so"].get("CStackNew", "cdecl")
    CStackNew.argtypes = []
    CStackNew.restype = CStack

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 65
if _libs["libpycm.so"].has("CStackErase", "cdecl"):
    CStackErase = _libs["libpycm.so"].get("CStackErase", "cdecl")
    CStackErase.argtypes = [CStack]
    CStackErase.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 66
if _libs["libpycm.so"].has("CStackCount", "cdecl"):
    CStackCount = _libs["libpycm.so"].get("CStackCount", "cdecl")
    CStackCount.argtypes = [CStack]
    CStackCount.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 67
if _libs["libpycm.so"].has("CStackPush", "cdecl"):
    CStackPush = _libs["libpycm.so"].get("CStackPush", "cdecl")
    CStackPush.argtypes = [CStack, POINTER(None)]
    CStackPush.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 68
if _libs["libpycm.so"].has("CStackTop", "cdecl"):
    CStackTop = _libs["libpycm.so"].get("CStackTop", "cdecl")
    CStackTop.argtypes = [CStack]
    CStackTop.restype = POINTER(c_ubyte)
    CStackTop.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 69
if _libs["libpycm.so"].has("CStackPop", "cdecl"):
    CStackPop = _libs["libpycm.so"].get("CStackPop", "cdecl")
    CStackPop.argtypes = [CStack]
    CStackPop.restype = POINTER(c_ubyte)
    CStackPop.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 70
if _libs["libpycm.so"].has("CQueueNew", "cdecl"):
    CQueueNew = _libs["libpycm.so"].get("CQueueNew", "cdecl")
    CQueueNew.argtypes = []
    CQueueNew.restype = CQueue

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 71
if _libs["libpycm.so"].has("CQueueErase", "cdecl"):
    CQueueErase = _libs["libpycm.so"].get("CQueueErase", "cdecl")
    CQueueErase.argtypes = [CQueue]
    CQueueErase.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 72
if _libs["libpycm.so"].has("CQueueCount", "cdecl"):
    CQueueCount = _libs["libpycm.so"].get("CQueueCount", "cdecl")
    CQueueCount.argtypes = [CQueue]
    CQueueCount.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 73
if _libs["libpycm.so"].has("CQueuePush", "cdecl"):
    CQueuePush = _libs["libpycm.so"].get("CQueuePush", "cdecl")
    CQueuePush.argtypes = [CQueue, POINTER(None)]
    CQueuePush.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 74
if _libs["libpycm.so"].has("CQueueTop", "cdecl"):
    CQueueTop = _libs["libpycm.so"].get("CQueueTop", "cdecl")
    CQueueTop.argtypes = [CQueue]
    CQueueTop.restype = POINTER(c_ubyte)
    CQueueTop.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 75
if _libs["libpycm.so"].has("CQueuePop", "cdecl"):
    CQueuePop = _libs["libpycm.so"].get("CQueuePop", "cdecl")
    CQueuePop.argtypes = [CQueue]
    CQueuePop.restype = POINTER(c_ubyte)
    CQueuePop.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 76
if _libs["libpycm.so"].has("CLListNew", "cdecl"):
    CLListNew = _libs["libpycm.so"].get("CLListNew", "cdecl")
    CLListNew.argtypes = []
    CLListNew.restype = CLList

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 77
if _libs["libpycm.so"].has("CLListErase", "cdecl"):
    CLListErase = _libs["libpycm.so"].get("CLListErase", "cdecl")
    CLListErase.argtypes = [CLList]
    CLListErase.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 78
if _libs["libpycm.so"].has("CLListCount", "cdecl"):
    CLListCount = _libs["libpycm.so"].get("CLListCount", "cdecl")
    CLListCount.argtypes = [CLList]
    CLListCount.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 79
if _libs["libpycm.so"].has("CLListAdd", "cdecl"):
    CLListAdd = _libs["libpycm.so"].get("CLListAdd", "cdecl")
    CLListAdd.argtypes = [CLList, POINTER(None)]
    CLListAdd.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 80
if _libs["libpycm.so"].has("CLListPrepend", "cdecl"):
    CLListPrepend = _libs["libpycm.so"].get("CLListPrepend", "cdecl")
    CLListPrepend.argtypes = [CLList, POINTER(None)]
    CLListPrepend.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 81
if _libs["libpycm.so"].has("CLListFirst", "cdecl"):
    CLListFirst = _libs["libpycm.so"].get("CLListFirst", "cdecl")
    CLListFirst.argtypes = [CLList]
    CLListFirst.restype = POINTER(c_ubyte)
    CLListFirst.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 82
if _libs["libpycm.so"].has("CLListLast", "cdecl"):
    CLListLast = _libs["libpycm.so"].get("CLListLast", "cdecl")
    CLListLast.argtypes = [CLList]
    CLListLast.restype = POINTER(c_ubyte)
    CLListLast.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 83
if _libs["libpycm.so"].has("CLListRemove", "cdecl"):
    CLListRemove = _libs["libpycm.so"].get("CLListRemove", "cdecl")
    CLListRemove.argtypes = [CLList, POINTER(None)]
    CLListRemove.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 84
if _libs["libpycm.so"].has("CLListFind", "cdecl"):
    CLListFind = _libs["libpycm.so"].get("CLListFind", "cdecl")
    CLListFind.argtypes = [CLList, POINTER(None)]
    CLListFind.restype = POINTER(c_ubyte)
    CLListFind.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 85
if _libs["libpycm.so"].has("CLListGiveIterator", "cdecl"):
    CLListGiveIterator = _libs["libpycm.so"].get("CLListGiveIterator", "cdecl")
    CLListGiveIterator.argtypes = [CLList]
    CLListGiveIterator.restype = CIterator

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 86
if _libs["libpycm.so"].has("CLListGiveBackwardIterator", "cdecl"):
    CLListGiveBackwardIterator = _libs["libpycm.so"].get("CLListGiveBackwardIterator", "cdecl")
    CLListGiveBackwardIterator.argtypes = [CLList]
    CLListGiveBackwardIterator.restype = CIterator

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 87
if _libs["libpycm.so"].has("CPtrHasherNew", "cdecl"):
    CPtrHasherNew = _libs["libpycm.so"].get("CPtrHasherNew", "cdecl")
    CPtrHasherNew.argtypes = [c_int, CValuator]
    CPtrHasherNew.restype = CHasher

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 88
if _libs["libpycm.so"].has("CStrHasherNew", "cdecl"):
    CStrHasherNew = _libs["libpycm.so"].get("CStrHasherNew", "cdecl")
    CStrHasherNew.argtypes = [c_int, CValuator]
    CStrHasherNew.restype = CHasher

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 89
if _libs["libpycm.so"].has("CLStrHasherNew", "cdecl"):
    CLStrHasherNew = _libs["libpycm.so"].get("CLStrHasherNew", "cdecl")
    CLStrHasherNew.argtypes = [c_int, CValuator]
    CLStrHasherNew.restype = CHasher

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 90
if _libs["libpycm.so"].has("CHasherNew", "cdecl"):
    CHasherNew = _libs["libpycm.so"].get("CHasherNew", "cdecl")
    CHasherNew.argtypes = [c_int, CValuator, CCoder, CTester]
    CHasherNew.restype = CHasher

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 91
if _libs["libpycm.so"].has("CHasherErase", "cdecl"):
    CHasherErase = _libs["libpycm.so"].get("CHasherErase", "cdecl")
    CHasherErase.argtypes = [CHasher]
    CHasherErase.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 92
if _libs["libpycm.so"].has("CHasherAdd", "cdecl"):
    CHasherAdd = _libs["libpycm.so"].get("CHasherAdd", "cdecl")
    CHasherAdd.argtypes = [CHasher, POINTER(None)]
    CHasherAdd.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 93
if _libs["libpycm.so"].has("CHasherFind", "cdecl"):
    CHasherFind = _libs["libpycm.so"].get("CHasherFind", "cdecl")
    CHasherFind.argtypes = [CHasher, POINTER(None)]
    CHasherFind.restype = POINTER(c_ubyte)
    CHasherFind.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 94
if _libs["libpycm.so"].has("CHasherFindPosition", "cdecl"):
    CHasherFindPosition = _libs["libpycm.so"].get("CHasherFindPosition", "cdecl")
    CHasherFindPosition.argtypes = [CHasher, POINTER(None), POINTER(c_int), POINTER(c_int)]
    CHasherFindPosition.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 95
if _libs["libpycm.so"].has("CHasherRemove", "cdecl"):
    CHasherRemove = _libs["libpycm.so"].get("CHasherRemove", "cdecl")
    CHasherRemove.argtypes = [CHasher, POINTER(None)]
    CHasherRemove.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 96
if _libs["libpycm.so"].has("CHasherGiveIterator", "cdecl"):
    CHasherGiveIterator = _libs["libpycm.so"].get("CHasherGiveIterator", "cdecl")
    CHasherGiveIterator.argtypes = [CHasher]
    CHasherGiveIterator.restype = CIterator

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 97
if _libs["libpycm.so"].has("CIteratorFinished", "cdecl"):
    CIteratorFinished = _libs["libpycm.so"].get("CIteratorFinished", "cdecl")
    CIteratorFinished.argtypes = [CIterator]
    CIteratorFinished.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 98
if _libs["libpycm.so"].has("CIteratorFirst", "cdecl"):
    CIteratorFirst = _libs["libpycm.so"].get("CIteratorFirst", "cdecl")
    CIteratorFirst.argtypes = [CIterator]
    CIteratorFirst.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 99
if _libs["libpycm.so"].has("CIteratorForth", "cdecl"):
    CIteratorForth = _libs["libpycm.so"].get("CIteratorForth", "cdecl")
    CIteratorForth.argtypes = [CIterator]
    CIteratorForth.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 100
if _libs["libpycm.so"].has("CIteratorDelete", "cdecl"):
    CIteratorDelete = _libs["libpycm.so"].get("CIteratorDelete", "cdecl")
    CIteratorDelete.argtypes = [CIterator]
    CIteratorDelete.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 101
if _libs["libpycm.so"].has("CIteratorItem", "cdecl"):
    CIteratorItem = _libs["libpycm.so"].get("CIteratorItem", "cdecl")
    CIteratorItem.argtypes = [CIterator]
    CIteratorItem.restype = POINTER(c_ubyte)
    CIteratorItem.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 102
if _libs["libpycm.so"].has("CIteratorStop", "cdecl"):
    CIteratorStop = _libs["libpycm.so"].get("CIteratorStop", "cdecl")
    CIteratorStop.argtypes = [CIterator]
    CIteratorStop.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 40
class struct__CmConnectRec(Structure):
    pass

CmConnect = POINTER(struct__CmConnectRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 40

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 41
class struct__CmConnectIteratorRec(Structure):
    pass

CmConnectIterator = POINTER(struct__CmConnectIteratorRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 41

enum_anon_5 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 49

CmConnectStatusNoData = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 49

CmConnectStatusData = (CmConnectStatusNoData + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 49

CmConnectStatusDelayed = (CmConnectStatusData + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 49

CmConnectStatusAbort = (CmConnectStatusDelayed + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 49

CmConnectStatus = enum_anon_5# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 49

enum_anon_6 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 58

CmConnectNormalCompletion = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 58

CmConnectNoHandler = (CmConnectNormalCompletion + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 58

CmConnectTimeoutDetection = (CmConnectNoHandler + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 58

CmConnectBreakDetection = (CmConnectTimeoutDetection + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 58

CmConnectErrorCondition = (CmConnectBreakDetection + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 58

CmConnectCondition = enum_anon_6# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 58

enum_anon_7 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorBadPort = 1# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorBadName = (CmErrorBadPort + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorBadHost = (CmErrorBadName + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorNoNameServer = (CmErrorBadHost + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorBadSocket = (CmErrorNoNameServer + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorBadEnvironment = (CmErrorBadSocket + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorBadMemory = (CmErrorBadEnvironment + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorRecovered = (CmErrorBadMemory + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

CmErrorCode = enum_anon_7# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 70

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 73
class struct__CmNameServerInfosRec(Structure):
    pass

CmNameServerInfos = POINTER(struct__CmNameServerInfosRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 72

struct__CmNameServerInfosRec.__slots__ = [
    'name',
    'host',
    'port',
    'firstPort',
    'ports',
    'repository',
]
struct__CmNameServerInfosRec._fields_ = [
    ('name', String),
    ('host', String),
    ('port', c_int),
    ('firstPort', c_int),
    ('ports', c_int),
    ('repository', String),
]

CmNameServerInfosRec = struct__CmNameServerInfosRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 81

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 84
class struct__CmConnectStatisticsRec(Structure):
    pass

CmConnectStatistics = POINTER(struct__CmConnectStatisticsRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 83

struct__CmConnectStatisticsRec.__slots__ = [
    'sent',
    'received',
    'bytes_sent',
    'bytes_received',
]
struct__CmConnectStatisticsRec._fields_ = [
    ('sent', c_int),
    ('received', c_int),
    ('bytes_sent', c_int),
    ('bytes_received', c_int),
]

CmConnectStatisticsRec = struct__CmConnectStatisticsRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 90

CmConnectPrinter = CFUNCTYPE(UNCHECKED(c_int), String, c_void_p)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 92

CmConnectFunction = CFUNCTYPE(UNCHECKED(None), )# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 94

CmConnectConnectionHandler = CFUNCTYPE(UNCHECKED(None), CmConnect)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 95

CmConnectReceiveHandler = CFUNCTYPE(UNCHECKED(CmConnectStatus), CmConnect)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 96

CmConnectRearmHandler = CFUNCTYPE(UNCHECKED(CmConnectStatus), CmConnect)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 97

CmConnectBuildPortHandler = CFUNCTYPE(UNCHECKED(c_int), )# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 98

CvtSwap = c_char * int(((((2 * sizeof(c_short)) + 1) + (2 * sizeof(c_int))) + 1))# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 36

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 38
class struct__CvtRec(Structure):
    pass

Cvt = POINTER(struct__CvtRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 38

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 40
if _libs["libpycm.so"].has("CvtForceStartup", "cdecl"):
    CvtForceStartup = _libs["libpycm.so"].get("CvtForceStartup", "cdecl")
    CvtForceStartup.argtypes = []
    CvtForceStartup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 41
if _libs["libpycm.so"].has("CvtStartup", "cdecl"):
    CvtStartup = _libs["libpycm.so"].get("CvtStartup", "cdecl")
    CvtStartup.argtypes = []
    CvtStartup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 42
if _libs["libpycm.so"].has("CvtCleanup", "cdecl"):
    CvtCleanup = _libs["libpycm.so"].get("CvtCleanup", "cdecl")
    CvtCleanup.argtypes = []
    CvtCleanup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 43
if _libs["libpycm.so"].has("CvtCheckBalance", "cdecl"):
    CvtCheckBalance = _libs["libpycm.so"].get("CvtCheckBalance", "cdecl")
    CvtCheckBalance.argtypes = []
    CvtCheckBalance.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 44
if _libs["libpycm.so"].has("CvtNew", "cdecl"):
    CvtNew = _libs["libpycm.so"].get("CvtNew", "cdecl")
    CvtNew.argtypes = [String]
    CvtNew.restype = Cvt

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 45
if _libs["libpycm.so"].has("CvtDelete", "cdecl"):
    CvtDelete = _libs["libpycm.so"].get("CvtDelete", "cdecl")
    CvtDelete.argtypes = [Cvt]
    CvtDelete.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 46
if _libs["libpycm.so"].has("CvtGetShort", "cdecl"):
    CvtGetShort = _libs["libpycm.so"].get("CvtGetShort", "cdecl")
    CvtGetShort.argtypes = [Cvt, POINTER(c_ubyte)]
    CvtGetShort.restype = c_short

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 47
if _libs["libpycm.so"].has("CvtPutShort", "cdecl"):
    CvtPutShort = _libs["libpycm.so"].get("CvtPutShort", "cdecl")
    CvtPutShort.argtypes = [c_short, POINTER(c_ubyte)]
    CvtPutShort.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 48
if _libs["libpycm.so"].has("CvtGetInt", "cdecl"):
    CvtGetInt = _libs["libpycm.so"].get("CvtGetInt", "cdecl")
    CvtGetInt.argtypes = [Cvt, POINTER(c_ubyte)]
    CvtGetInt.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 49
if _libs["libpycm.so"].has("CvtPutInt", "cdecl"):
    CvtPutInt = _libs["libpycm.so"].get("CvtPutInt", "cdecl")
    CvtPutInt.argtypes = [c_int, POINTER(c_ubyte)]
    CvtPutInt.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 50
if _libs["libpycm.so"].has("CvtPutFloat", "cdecl"):
    CvtPutFloat = _libs["libpycm.so"].get("CvtPutFloat", "cdecl")
    CvtPutFloat.argtypes = [c_float, POINTER(c_ubyte)]
    CvtPutFloat.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 51
if _libs["libpycm.so"].has("CvtGetFloat", "cdecl"):
    CvtGetFloat = _libs["libpycm.so"].get("CvtGetFloat", "cdecl")
    CvtGetFloat.argtypes = [POINTER(c_ubyte)]
    CvtGetFloat.restype = c_float

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 52
if _libs["libpycm.so"].has("CvtPutFloats", "cdecl"):
    CvtPutFloats = _libs["libpycm.so"].get("CvtPutFloats", "cdecl")
    CvtPutFloats.argtypes = [POINTER(c_ubyte), c_int]
    CvtPutFloats.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 53
if _libs["libpycm.so"].has("CvtGetFloats", "cdecl"):
    CvtGetFloats = _libs["libpycm.so"].get("CvtGetFloats", "cdecl")
    CvtGetFloats.argtypes = [POINTER(c_ubyte), c_int]
    CvtGetFloats.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 54
if _libs["libpycm.so"].has("CvtPutDouble", "cdecl"):
    CvtPutDouble = _libs["libpycm.so"].get("CvtPutDouble", "cdecl")
    CvtPutDouble.argtypes = [c_double, POINTER(c_ubyte)]
    CvtPutDouble.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 55
if _libs["libpycm.so"].has("CvtGetDouble", "cdecl"):
    CvtGetDouble = _libs["libpycm.so"].get("CvtGetDouble", "cdecl")
    CvtGetDouble.argtypes = [POINTER(c_ubyte)]
    CvtGetDouble.restype = c_double

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 56
if _libs["libpycm.so"].has("CvtPutDoubles", "cdecl"):
    CvtPutDoubles = _libs["libpycm.so"].get("CvtPutDoubles", "cdecl")
    CvtPutDoubles.argtypes = [POINTER(c_ubyte), c_int]
    CvtPutDoubles.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 57
if _libs["libpycm.so"].has("CvtGetDoubles", "cdecl"):
    CvtGetDoubles = _libs["libpycm.so"].get("CvtGetDoubles", "cdecl")
    CvtGetDoubles.argtypes = [POINTER(c_ubyte), c_int]
    CvtGetDoubles.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 58
if _libs["libpycm.so"].has("CvtToText", "cdecl"):
    CvtToText = _libs["libpycm.so"].get("CvtToText", "cdecl")
    CvtToText.argtypes = [Cvt]
    if sizeof(c_int) == sizeof(c_void_p):
        CvtToText.restype = ReturnString
    else:
        CvtToText.restype = String
        CvtToText.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 59
if _libs["libpycm.so"].has("CvtGetSwap", "cdecl"):
    CvtGetSwap = _libs["libpycm.so"].get("CvtGetSwap", "cdecl")
    CvtGetSwap.argtypes = []
    if sizeof(c_int) == sizeof(c_void_p):
        CvtGetSwap.restype = ReturnString
    else:
        CvtGetSwap.restype = String
        CvtGetSwap.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 107
if _libs["libpycm.so"].has("CmConnectForceStartup", "cdecl"):
    CmConnectForceStartup = _libs["libpycm.so"].get("CmConnectForceStartup", "cdecl")
    CmConnectForceStartup.argtypes = []
    CmConnectForceStartup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 108
if _libs["libpycm.so"].has("CmConnectInitialize", "cdecl"):
    CmConnectInitialize = _libs["libpycm.so"].get("CmConnectInitialize", "cdecl")
    CmConnectInitialize.argtypes = []
    CmConnectInitialize.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 109
if _libs["libpycm.so"].has("CmConnectCleanup", "cdecl"):
    CmConnectCleanup = _libs["libpycm.so"].get("CmConnectCleanup", "cdecl")
    CmConnectCleanup.argtypes = []
    CmConnectCleanup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 110
if _libs["libpycm.so"].has("CmConnectCheckBalance", "cdecl"):
    CmConnectCheckBalance = _libs["libpycm.so"].get("CmConnectCheckBalance", "cdecl")
    CmConnectCheckBalance.argtypes = []
    CmConnectCheckBalance.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 111
if _libs["libpycm.so"].has("CmConnectInstallPrinter", "cdecl"):
    CmConnectInstallPrinter = _libs["libpycm.so"].get("CmConnectInstallPrinter", "cdecl")
    CmConnectInstallPrinter.argtypes = [CmConnectPrinter]
    CmConnectInstallPrinter.restype = CmConnectPrinter

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 112
if _libs["libpycm.so"].has("CmConnectGetDomain", "cdecl"):
    CmConnectGetDomain = _libs["libpycm.so"].get("CmConnectGetDomain", "cdecl")
    CmConnectGetDomain.argtypes = []
    if sizeof(c_int) == sizeof(c_void_p):
        CmConnectGetDomain.restype = ReturnString
    else:
        CmConnectGetDomain.restype = String
        CmConnectGetDomain.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 113
if _libs["libpycm.so"].has("CmConnectSetDomain", "cdecl"):
    CmConnectSetDomain = _libs["libpycm.so"].get("CmConnectSetDomain", "cdecl")
    CmConnectSetDomain.argtypes = [String]
    CmConnectSetDomain.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 114
if _libs["libpycm.so"].has("CmConnectExit", "cdecl"):
    CmConnectExit = _libs["libpycm.so"].get("CmConnectExit", "cdecl")
    CmConnectExit.argtypes = [CmErrorCode]
    CmConnectExit.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 115
if _libs["libpycm.so"].has("CmConnectInstallCHandler", "cdecl"):
    CmConnectInstallCHandler = _libs["libpycm.so"].get("CmConnectInstallCHandler", "cdecl")
    CmConnectInstallCHandler.argtypes = [CmConnectConnectionHandler]
    CmConnectInstallCHandler.restype = CmConnectConnectionHandler

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 116
if _libs["libpycm.so"].has("CmConnectInstallDHandler", "cdecl"):
    CmConnectInstallDHandler = _libs["libpycm.so"].get("CmConnectInstallDHandler", "cdecl")
    CmConnectInstallDHandler.argtypes = [CmConnectConnectionHandler]
    CmConnectInstallDHandler.restype = CmConnectConnectionHandler

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 117
if _libs["libpycm.so"].has("CmConnectDebugOn", "cdecl"):
    CmConnectDebugOn = _libs["libpycm.so"].get("CmConnectDebugOn", "cdecl")
    CmConnectDebugOn.argtypes = []
    CmConnectDebugOn.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 118
if _libs["libpycm.so"].has("CmConnectDebugOff", "cdecl"):
    CmConnectDebugOff = _libs["libpycm.so"].get("CmConnectDebugOff", "cdecl")
    CmConnectDebugOff.argtypes = []
    CmConnectDebugOff.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 119
if _libs["libpycm.so"].has("CmConnectTime", "cdecl"):
    CmConnectTime = _libs["libpycm.so"].get("CmConnectTime", "cdecl")
    CmConnectTime.argtypes = []
    if sizeof(c_int) == sizeof(c_void_p):
        CmConnectTime.restype = ReturnString
    else:
        CmConnectTime.restype = String
        CmConnectTime.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 120
if _libs["libpycm.so"].has("CmConnectStartupAsServer", "cdecl"):
    CmConnectStartupAsServer = _libs["libpycm.so"].get("CmConnectStartupAsServer", "cdecl")
    CmConnectStartupAsServer.argtypes = [String]
    CmConnectStartupAsServer.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 121
if _libs["libpycm.so"].has("CmConnectStartupAsMS", "cdecl"):
    CmConnectStartupAsMS = _libs["libpycm.so"].get("CmConnectStartupAsMS", "cdecl")
    CmConnectStartupAsMS.argtypes = [String]
    CmConnectStartupAsMS.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 122
if _libs["libpycm.so"].has("CmConnectOpenServer", "cdecl"):
    CmConnectOpenServer = _libs["libpycm.so"].get("CmConnectOpenServer", "cdecl")
    CmConnectOpenServer.argtypes = [String]
    CmConnectOpenServer.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 123
if _libs["libpycm.so"].has("CmConnectOpenMultipleServer", "cdecl"):
    CmConnectOpenMultipleServer = _libs["libpycm.so"].get("CmConnectOpenMultipleServer", "cdecl")
    CmConnectOpenMultipleServer.argtypes = [String]
    CmConnectOpenMultipleServer.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 124
if _libs["libpycm.so"].has("CmConnectCloseServer", "cdecl"):
    CmConnectCloseServer = _libs["libpycm.so"].get("CmConnectCloseServer", "cdecl")
    CmConnectCloseServer.argtypes = [String]
    CmConnectCloseServer.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 125
if _libs["libpycm.so"].has("CmConnectSelectServer", "cdecl"):
    CmConnectSelectServer = _libs["libpycm.so"].get("CmConnectSelectServer", "cdecl")
    CmConnectSelectServer.argtypes = [String]
    CmConnectSelectServer.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 126
if _libs["libpycm.so"].has("CmServerSetComment", "cdecl"):
    CmServerSetComment = _libs["libpycm.so"].get("CmServerSetComment", "cdecl")
    CmServerSetComment.argtypes = [String]
    CmServerSetComment.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 127
if _libs["libpycm.so"].has("CmServerGetComment", "cdecl"):
    CmServerGetComment = _libs["libpycm.so"].get("CmServerGetComment", "cdecl")
    CmServerGetComment.argtypes = []
    if sizeof(c_int) == sizeof(c_void_p):
        CmServerGetComment.restype = ReturnString
    else:
        CmServerGetComment.restype = String
        CmServerGetComment.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 128
if _libs["libpycm.so"].has("CmConnectWhoAmI", "cdecl"):
    CmConnectWhoAmI = _libs["libpycm.so"].get("CmConnectWhoAmI", "cdecl")
    CmConnectWhoAmI.argtypes = []
    CmConnectWhoAmI.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 129
if _libs["libpycm.so"].has("CmConnectNew", "cdecl"):
    CmConnectNew = _libs["libpycm.so"].get("CmConnectNew", "cdecl")
    CmConnectNew.argtypes = [String]
    CmConnectNew.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 130
if _libs["libpycm.so"].has("CmConnectNewWithAddress", "cdecl"):
    CmConnectNewWithAddress = _libs["libpycm.so"].get("CmConnectNewWithAddress", "cdecl")
    CmConnectNewWithAddress.argtypes = [CmConnect, String, c_int, String]
    CmConnectNewWithAddress.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 131
if _libs["libpycm.so"].has("CmConnectNewWithSocket", "cdecl"):
    CmConnectNewWithSocket = _libs["libpycm.so"].get("CmConnectNewWithSocket", "cdecl")
    CmConnectNewWithSocket.argtypes = [String, c_int]
    CmConnectNewWithSocket.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 132
if _libs["libpycm.so"].has("CmConnectGetSocketId", "cdecl"):
    CmConnectGetSocketId = _libs["libpycm.so"].get("CmConnectGetSocketId", "cdecl")
    CmConnectGetSocketId.argtypes = [CmConnect]
    CmConnectGetSocketId.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 133
if _libs["libpycm.so"].has("CmConnectGetMessage", "cdecl"):
    CmConnectGetMessage = _libs["libpycm.so"].get("CmConnectGetMessage", "cdecl")
    CmConnectGetMessage.argtypes = [CmConnect]
    CmConnectGetMessage.restype = CmMessage

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 134
if _libs["libpycm.so"].has("CmConnectPushMessage", "cdecl"):
    CmConnectPushMessage = _libs["libpycm.so"].get("CmConnectPushMessage", "cdecl")
    CmConnectPushMessage.argtypes = [CmConnect]
    CmConnectPushMessage.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 135
if _libs["libpycm.so"].has("CmConnectTopMessage", "cdecl"):
    CmConnectTopMessage = _libs["libpycm.so"].get("CmConnectTopMessage", "cdecl")
    CmConnectTopMessage.argtypes = [CmConnect]
    CmConnectTopMessage.restype = CmMessage

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 136
if _libs["libpycm.so"].has("CmConnectPopMessage", "cdecl"):
    CmConnectPopMessage = _libs["libpycm.so"].get("CmConnectPopMessage", "cdecl")
    CmConnectPopMessage.argtypes = [CmConnect]
    CmConnectPopMessage.restype = CmMessage

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 137
if _libs["libpycm.so"].has("CmConnectIsNameServer", "cdecl"):
    CmConnectIsNameServer = _libs["libpycm.so"].get("CmConnectIsNameServer", "cdecl")
    CmConnectIsNameServer.argtypes = [CmConnect]
    CmConnectIsNameServer.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 138
if _libs["libpycm.so"].has("CmConnectReceive", "cdecl"):
    CmConnectReceive = _libs["libpycm.so"].get("CmConnectReceive", "cdecl")
    CmConnectReceive.argtypes = [CmConnect, String, c_int]
    CmConnectReceive.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 139
if _libs["libpycm.so"].has("CmConnectSend", "cdecl"):
    CmConnectSend = _libs["libpycm.so"].get("CmConnectSend", "cdecl")
    CmConnectSend.argtypes = [CmConnect, String, c_int]
    CmConnectSend.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 140
if _libs["libpycm.so"].has("CmConnectGetReference", "cdecl"):
    CmConnectGetReference = _libs["libpycm.so"].get("CmConnectGetReference", "cdecl")
    CmConnectGetReference.argtypes = [String]
    CmConnectGetReference.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 141
if _libs["libpycm.so"].has("CmConnectGetNthReference", "cdecl"):
    CmConnectGetNthReference = _libs["libpycm.so"].get("CmConnectGetNthReference", "cdecl")
    CmConnectGetNthReference.argtypes = [String, c_int]
    CmConnectGetNthReference.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 142
if _libs["libpycm.so"].has("CmConnectGetName", "cdecl"):
    CmConnectGetName = _libs["libpycm.so"].get("CmConnectGetName", "cdecl")
    CmConnectGetName.argtypes = [CmConnect]
    if sizeof(c_int) == sizeof(c_void_p):
        CmConnectGetName.restype = ReturnString
    else:
        CmConnectGetName.restype = String
        CmConnectGetName.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 143
if _libs["libpycm.so"].has("CmConnectGetServer", "cdecl"):
    CmConnectGetServer = _libs["libpycm.so"].get("CmConnectGetServer", "cdecl")
    CmConnectGetServer.argtypes = [CmConnect]
    CmConnectGetServer.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 144
if _libs["libpycm.so"].has("CmConnectGetNameServer", "cdecl"):
    CmConnectGetNameServer = _libs["libpycm.so"].get("CmConnectGetNameServer", "cdecl")
    CmConnectGetNameServer.argtypes = []
    CmConnectGetNameServer.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 145
if _libs["libpycm.so"].has("CmConnectSetName", "cdecl"):
    CmConnectSetName = _libs["libpycm.so"].get("CmConnectSetName", "cdecl")
    CmConnectSetName.argtypes = [CmConnect, String]
    CmConnectSetName.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 146
if _libs["libpycm.so"].has("CmConnectIsLocal", "cdecl"):
    CmConnectIsLocal = _libs["libpycm.so"].get("CmConnectIsLocal", "cdecl")
    CmConnectIsLocal.argtypes = [CmConnect]
    CmConnectIsLocal.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 147
if _libs["libpycm.so"].has("CmConnectIsMultiple", "cdecl"):
    CmConnectIsMultiple = _libs["libpycm.so"].get("CmConnectIsMultiple", "cdecl")
    CmConnectIsMultiple.argtypes = [CmConnect]
    CmConnectIsMultiple.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 148
if _libs["libpycm.so"].has("CmConnectSetMultiple", "cdecl"):
    CmConnectSetMultiple = _libs["libpycm.so"].get("CmConnectSetMultiple", "cdecl")
    CmConnectSetMultiple.argtypes = [CmConnect]
    CmConnectSetMultiple.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 149
if _libs["libpycm.so"].has("CmConnectSetPort", "cdecl"):
    CmConnectSetPort = _libs["libpycm.so"].get("CmConnectSetPort", "cdecl")
    CmConnectSetPort.argtypes = [CmConnect, c_int]
    CmConnectSetPort.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 150
if _libs["libpycm.so"].has("CmConnectSnprint", "cdecl"):
    CmConnectSnprint = _libs["libpycm.so"].get("CmConnectSnprint", "cdecl")
    CmConnectSnprint.argtypes = [CmConnect, String, c_int]
    CmConnectSnprint.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 151
if _libs["libpycm.so"].has("CmConnectSetSocketSize", "cdecl"):
    CmConnectSetSocketSize = _libs["libpycm.so"].get("CmConnectSetSocketSize", "cdecl")
    CmConnectSetSocketSize.argtypes = [c_int, c_int, String]
    CmConnectSetSocketSize.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 152
if _libs["libpycm.so"].has("CmConnectGetPort", "cdecl"):
    CmConnectGetPort = _libs["libpycm.so"].get("CmConnectGetPort", "cdecl")
    CmConnectGetPort.argtypes = [CmConnect]
    CmConnectGetPort.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 153
if _libs["libpycm.so"].has("CmConnectGetHost", "cdecl"):
    CmConnectGetHost = _libs["libpycm.so"].get("CmConnectGetHost", "cdecl")
    CmConnectGetHost.argtypes = [CmConnect]
    if sizeof(c_int) == sizeof(c_void_p):
        CmConnectGetHost.restype = ReturnString
    else:
        CmConnectGetHost.restype = String
        CmConnectGetHost.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 154
if _libs["libpycm.so"].has("CmConnectSetHost", "cdecl"):
    CmConnectSetHost = _libs["libpycm.so"].get("CmConnectSetHost", "cdecl")
    CmConnectSetHost.argtypes = [CmConnect, String]
    CmConnectSetHost.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 155
if _libs["libpycm.so"].has("CmConnectGetOwner", "cdecl"):
    CmConnectGetOwner = _libs["libpycm.so"].get("CmConnectGetOwner", "cdecl")
    CmConnectGetOwner.argtypes = [CmConnect]
    if sizeof(c_int) == sizeof(c_void_p):
        CmConnectGetOwner.restype = ReturnString
    else:
        CmConnectGetOwner.restype = String
        CmConnectGetOwner.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 156
if _libs["libpycm.so"].has("CmConnectSetOwner", "cdecl"):
    CmConnectSetOwner = _libs["libpycm.so"].get("CmConnectSetOwner", "cdecl")
    CmConnectSetOwner.argtypes = [CmConnect, String]
    CmConnectSetOwner.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 157
if _libs["libpycm.so"].has("CmConnectGetIterator", "cdecl"):
    CmConnectGetIterator = _libs["libpycm.so"].get("CmConnectGetIterator", "cdecl")
    CmConnectGetIterator.argtypes = []
    CmConnectGetIterator.restype = CmConnectIterator

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 158
if _libs["libpycm.so"].has("CmConnectIteratorDelete", "cdecl"):
    CmConnectIteratorDelete = _libs["libpycm.so"].get("CmConnectIteratorDelete", "cdecl")
    CmConnectIteratorDelete.argtypes = [CmConnectIterator]
    CmConnectIteratorDelete.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 159
if _libs["libpycm.so"].has("CmConnectGetNextAlive", "cdecl"):
    CmConnectGetNextAlive = _libs["libpycm.so"].get("CmConnectGetNextAlive", "cdecl")
    CmConnectGetNextAlive.argtypes = [CmConnectIterator]
    CmConnectGetNextAlive.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 160
if _libs["libpycm.so"].has("CmConnectGetNext", "cdecl"):
    CmConnectGetNext = _libs["libpycm.so"].get("CmConnectGetNext", "cdecl")
    CmConnectGetNext.argtypes = [CmConnectIterator]
    CmConnectGetNext.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 161
if _libs["libpycm.so"].has("CmConnectScan", "cdecl"):
    CmConnectScan = _libs["libpycm.so"].get("CmConnectScan", "cdecl")
    CmConnectScan.argtypes = [CmConnectIterator]
    CmConnectScan.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 162
if _libs["libpycm.so"].has("CmConnectInstallReceiveHandler", "cdecl"):
    CmConnectInstallReceiveHandler = _libs["libpycm.so"].get("CmConnectInstallReceiveHandler", "cdecl")
    CmConnectInstallReceiveHandler.argtypes = [CmConnect, CmConnectReceiveHandler]
    CmConnectInstallReceiveHandler.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 163
if _libs["libpycm.so"].has("CmConnectInstallRearmHandler", "cdecl"):
    CmConnectInstallRearmHandler = _libs["libpycm.so"].get("CmConnectInstallRearmHandler", "cdecl")
    CmConnectInstallRearmHandler.argtypes = [CmConnect, CmConnectRearmHandler]
    CmConnectInstallRearmHandler.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 164
if _libs["libpycm.so"].has("CmConnectInitData", "cdecl"):
    CmConnectInitData = _libs["libpycm.so"].get("CmConnectInitData", "cdecl")
    CmConnectInitData.argtypes = [CmConnect, CmConnectReceiveHandler, CmConnectRearmHandler]
    CmConnectInitData.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 165
if _libs["libpycm.so"].has("CmConnectInitHandlers", "cdecl"):
    CmConnectInitHandlers = _libs["libpycm.so"].get("CmConnectInitHandlers", "cdecl")
    CmConnectInitHandlers.argtypes = [CmConnect, CmConnectReceiveHandler, CmConnectRearmHandler]
    CmConnectInitHandlers.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 166
if _libs["libpycm.so"].has("CmConnectInstallMessage", "cdecl"):
    CmConnectInstallMessage = _libs["libpycm.so"].get("CmConnectInstallMessage", "cdecl")
    CmConnectInstallMessage.argtypes = [CmConnect, CmMessage]
    CmConnectInstallMessage.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 167
if _libs["libpycm.so"].has("CmConnectInstallMessageIterator", "cdecl"):
    CmConnectInstallMessageIterator = _libs["libpycm.so"].get("CmConnectInstallMessageIterator", "cdecl")
    CmConnectInstallMessageIterator.argtypes = [CmConnect, CmMessageIterator]
    CmConnectInstallMessageIterator.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 168
if _libs["libpycm.so"].has("CmConnectInstallNoTimeOut", "cdecl"):
    CmConnectInstallNoTimeOut = _libs["libpycm.so"].get("CmConnectInstallNoTimeOut", "cdecl")
    CmConnectInstallNoTimeOut.argtypes = [CmConnect]
    CmConnectInstallNoTimeOut.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 169
if _libs["libpycm.so"].has("CmConnectInstallTimeOut", "cdecl"):
    CmConnectInstallTimeOut = _libs["libpycm.so"].get("CmConnectInstallTimeOut", "cdecl")
    CmConnectInstallTimeOut.argtypes = [CmConnect, c_int, c_int]
    CmConnectInstallTimeOut.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 170
if _libs["libpycm.so"].has("CmConnectKill", "cdecl"):
    CmConnectKill = _libs["libpycm.so"].get("CmConnectKill", "cdecl")
    CmConnectKill.argtypes = [CmConnect]
    CmConnectKill.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 171
if _libs["libpycm.so"].has("CmConnectGetComment", "cdecl"):
    CmConnectGetComment = _libs["libpycm.so"].get("CmConnectGetComment", "cdecl")
    CmConnectGetComment.argtypes = [CmConnect]
    if sizeof(c_int) == sizeof(c_void_p):
        CmConnectGetComment.restype = ReturnString
    else:
        CmConnectGetComment.restype = String
        CmConnectGetComment.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 172
if _libs["libpycm.so"].has("CmConnectGetStatistics", "cdecl"):
    CmConnectGetStatistics = _libs["libpycm.so"].get("CmConnectGetStatistics", "cdecl")
    CmConnectGetStatistics.argtypes = [CmConnect, POINTER(CmConnectStatisticsRec)]
    CmConnectGetStatistics.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 173
if _libs["libpycm.so"].has("CmConnectCheck", "cdecl"):
    CmConnectCheck = _libs["libpycm.so"].get("CmConnectCheck", "cdecl")
    CmConnectCheck.argtypes = []
    CmConnectCheck.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 174
if _libs["libpycm.so"].has("CmConnectWait", "cdecl"):
    CmConnectWait = _libs["libpycm.so"].get("CmConnectWait", "cdecl")
    CmConnectWait.argtypes = []
    CmConnectWait.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 175
if _libs["libpycm.so"].has("CmConnectWaitOnIterator", "cdecl"):
    CmConnectWaitOnIterator = _libs["libpycm.so"].get("CmConnectWaitOnIterator", "cdecl")
    CmConnectWaitOnIterator.argtypes = [CmMessageIterator]
    CmConnectWaitOnIterator.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 176
if _libs["libpycm.so"].has("CmConnectWaitWithTimeout", "cdecl"):
    CmConnectWaitWithTimeout = _libs["libpycm.so"].get("CmConnectWaitWithTimeout", "cdecl")
    CmConnectWaitWithTimeout.argtypes = [c_double]
    CmConnectWaitWithTimeout.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 177
if _libs["libpycm.so"].has("CmConnectCheckInputData", "cdecl"):
    CmConnectCheckInputData = _libs["libpycm.so"].get("CmConnectCheckInputData", "cdecl")
    CmConnectCheckInputData.argtypes = [CmConnect]
    CmConnectCheckInputData.restype = CmConnectStatus

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 178
if _libs["libpycm.so"].has("CmNameServerGetInfos", "cdecl"):
    CmNameServerGetInfos = _libs["libpycm.so"].get("CmNameServerGetInfos", "cdecl")
    CmNameServerGetInfos.argtypes = []
    CmNameServerGetInfos.restype = CmNameServerInfos

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 179
if _libs["libpycm.so"].has("CmConnectTestPort", "cdecl"):
    CmConnectTestPort = _libs["libpycm.so"].get("CmConnectTestPort", "cdecl")
    CmConnectTestPort.argtypes = [c_int]
    CmConnectTestPort.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 4
class struct__CmTransactionRec(Structure):
    pass

CmTransaction = POINTER(struct__CmTransactionRec)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 4

enum_anon_8 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 11

CmTransactionClosed = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 11

CmTransactionPending = (CmTransactionClosed + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 11

CmTransactionTerminated = (CmTransactionPending + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 11

CmTransactionState = enum_anon_8# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 11

enum_anon_9 = c_int# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 18

CmTransactionOk = 0# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 18

CmTransactionNotFound = (CmTransactionOk + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 18

CmTransactionAlreadyClosed = (CmTransactionNotFound + 1)# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 18

CmTransactionStatus = enum_anon_9# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 18

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 20
if _libs["libpycm.so"].has("CmOpenTransaction", "cdecl"):
    CmOpenTransaction = _libs["libpycm.so"].get("CmOpenTransaction", "cdecl")
    CmOpenTransaction.argtypes = [String, POINTER(None)]
    CmOpenTransaction.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 21
if _libs["libpycm.so"].has("CmCloseTransaction", "cdecl"):
    CmCloseTransaction = _libs["libpycm.so"].get("CmCloseTransaction", "cdecl")
    CmCloseTransaction.argtypes = [c_int]
    CmCloseTransaction.restype = CmTransactionStatus

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 22
if _libs["libpycm.so"].has("CmTerminateTransaction", "cdecl"):
    CmTerminateTransaction = _libs["libpycm.so"].get("CmTerminateTransaction", "cdecl")
    CmTerminateTransaction.argtypes = [c_int]
    CmTerminateTransaction.restype = CmTransactionStatus

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 23
if _libs["libpycm.so"].has("CmRestartTransaction", "cdecl"):
    CmRestartTransaction = _libs["libpycm.so"].get("CmRestartTransaction", "cdecl")
    CmRestartTransaction.argtypes = [c_int]
    CmRestartTransaction.restype = CmTransactionStatus

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 24
if _libs["libpycm.so"].has("CmGetTransactionState", "cdecl"):
    CmGetTransactionState = _libs["libpycm.so"].get("CmGetTransactionState", "cdecl")
    CmGetTransactionState.argtypes = [c_int]
    CmGetTransactionState.restype = CmTransactionState

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 25
if _libs["libpycm.so"].has("CmGetTransactionInfo", "cdecl"):
    CmGetTransactionInfo = _libs["libpycm.so"].get("CmGetTransactionInfo", "cdecl")
    CmGetTransactionInfo.argtypes = [c_int]
    if sizeof(c_int) == sizeof(c_void_p):
        CmGetTransactionInfo.restype = ReturnString
    else:
        CmGetTransactionInfo.restype = String
        CmGetTransactionInfo.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 26
if _libs["libpycm.so"].has("CmGetTransactionObject", "cdecl"):
    CmGetTransactionObject = _libs["libpycm.so"].get("CmGetTransactionObject", "cdecl")
    CmGetTransactionObject.argtypes = [c_int]
    CmGetTransactionObject.restype = POINTER(c_ubyte)
    CmGetTransactionObject.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 27
if _libs["libpycm.so"].has("CmIsTransactionTerminated", "cdecl"):
    CmIsTransactionTerminated = _libs["libpycm.so"].get("CmIsTransactionTerminated", "cdecl")
    CmIsTransactionTerminated.argtypes = [c_int]
    CmIsTransactionTerminated.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 28
if _libs["libpycm.so"].has("CmTerminatedTransactionCount", "cdecl"):
    CmTerminatedTransactionCount = _libs["libpycm.so"].get("CmTerminatedTransactionCount", "cdecl")
    CmTerminatedTransactionCount.argtypes = []
    CmTerminatedTransactionCount.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 29
if _libs["libpycm.so"].has("CmDumpTransactions", "cdecl"):
    CmDumpTransactions = _libs["libpycm.so"].get("CmDumpTransactions", "cdecl")
    CmDumpTransactions.argtypes = []
    CmDumpTransactions.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 90
if _libs["libpycm.so"].has("CmMessageForceStartup", "cdecl"):
    CmMessageForceStartup = _libs["libpycm.so"].get("CmMessageForceStartup", "cdecl")
    CmMessageForceStartup.argtypes = [String]
    CmMessageForceStartup.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 91
if _libs["libpycm.so"].has("CmMessageInitialize", "cdecl"):
    CmMessageInitialize = _libs["libpycm.so"].get("CmMessageInitialize", "cdecl")
    CmMessageInitialize.argtypes = []
    CmMessageInitialize.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 92
if _libs["libpycm.so"].has("CmMessageStartup", "cdecl"):
    CmMessageStartup = _libs["libpycm.so"].get("CmMessageStartup", "cdecl")
    CmMessageStartup.argtypes = [String]
    CmMessageStartup.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 93
if _libs["libpycm.so"].has("CmMessageStartupMultiple", "cdecl"):
    CmMessageStartupMultiple = _libs["libpycm.so"].get("CmMessageStartupMultiple", "cdecl")
    CmMessageStartupMultiple.argtypes = [String]
    CmMessageStartupMultiple.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 94
if _libs["libpycm.so"].has("CmMessageOpenServer", "cdecl"):
    CmMessageOpenServer = _libs["libpycm.so"].get("CmMessageOpenServer", "cdecl")
    CmMessageOpenServer.argtypes = [String]
    CmMessageOpenServer.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 95
if _libs["libpycm.so"].has("CmMessageOpenMultipleServer", "cdecl"):
    CmMessageOpenMultipleServer = _libs["libpycm.so"].get("CmMessageOpenMultipleServer", "cdecl")
    CmMessageOpenMultipleServer.argtypes = [String]
    CmMessageOpenMultipleServer.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 96
if _libs["libpycm.so"].has("CmMessageCloseServer", "cdecl"):
    CmMessageCloseServer = _libs["libpycm.so"].get("CmMessageCloseServer", "cdecl")
    CmMessageCloseServer.argtypes = [String]
    CmMessageCloseServer.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 97
if _libs["libpycm.so"].has("CmMessageCleanup", "cdecl"):
    CmMessageCleanup = _libs["libpycm.so"].get("CmMessageCleanup", "cdecl")
    CmMessageCleanup.argtypes = []
    CmMessageCleanup.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 98
if _libs["libpycm.so"].has("CmMessageCheckBalance", "cdecl"):
    CmMessageCheckBalance = _libs["libpycm.so"].get("CmMessageCheckBalance", "cdecl")
    CmMessageCheckBalance.argtypes = []
    CmMessageCheckBalance.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 99
if _libs["libpycm.so"].has("CmMessageInstallPrinter", "cdecl"):
    CmMessageInstallPrinter = _libs["libpycm.so"].get("CmMessageInstallPrinter", "cdecl")
    CmMessageInstallPrinter.argtypes = [CmConnectPrinter]
    CmMessageInstallPrinter.restype = CmConnectPrinter

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 100
if _libs["libpycm.so"].has("CmMessageNew", "cdecl"):
    CmMessageNew = _libs["libpycm.so"].get("CmMessageNew", "cdecl")
    CmMessageNew.argtypes = []
    CmMessageNew.restype = CmMessage

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 101
if _libs["libpycm.so"].has("CmMessageDelete", "cdecl"):
    CmMessageDelete = _libs["libpycm.so"].get("CmMessageDelete", "cdecl")
    CmMessageDelete.argtypes = [CmMessage]
    CmMessageDelete.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 102
if _libs["libpycm.so"].has("CmMessageReset", "cdecl"):
    CmMessageReset = _libs["libpycm.so"].get("CmMessageReset", "cdecl")
    CmMessageReset.argtypes = [CmMessage]
    CmMessageReset.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 103
if _libs["libpycm.so"].has("CmMessageSetType", "cdecl"):
    CmMessageSetType = _libs["libpycm.so"].get("CmMessageSetType", "cdecl")
    CmMessageSetType.argtypes = [CmMessage, String]
    CmMessageSetType.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 104
if _libs["libpycm.so"].has("CmMessageGetType", "cdecl"):
    CmMessageGetType = _libs["libpycm.so"].get("CmMessageGetType", "cdecl")
    CmMessageGetType.argtypes = [CmMessage]
    if sizeof(c_int) == sizeof(c_void_p):
        CmMessageGetType.restype = ReturnString
    else:
        CmMessageGetType.restype = String
        CmMessageGetType.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 105
if _libs["libpycm.so"].has("CmMessageGetState", "cdecl"):
    CmMessageGetState = _libs["libpycm.so"].get("CmMessageGetState", "cdecl")
    CmMessageGetState.argtypes = [CmMessage]
    CmMessageGetState.restype = CmMessageState

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 106
if _libs["libpycm.so"].has("CmMessageGetConnect", "cdecl"):
    CmMessageGetConnect = _libs["libpycm.so"].get("CmMessageGetConnect", "cdecl")
    CmMessageGetConnect.argtypes = [CmMessage]
    CmMessageGetConnect.restype = CmConnect

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 107
if _libs["libpycm.so"].has("CmMessageGetMessageLength", "cdecl"):
    CmMessageGetMessageLength = _libs["libpycm.so"].get("CmMessageGetMessageLength", "cdecl")
    CmMessageGetMessageLength.argtypes = [CmMessage]
    CmMessageGetMessageLength.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 108
if _libs["libpycm.so"].has("CmMessageSend", "cdecl"):
    CmMessageSend = _libs["libpycm.so"].get("CmMessageSend", "cdecl")
    CmMessageSend.argtypes = [CmMessage, String]
    CmMessageSend.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 109
if _libs["libpycm.so"].has("CmMessagePost", "cdecl"):
    CmMessagePost = _libs["libpycm.so"].get("CmMessagePost", "cdecl")
    CmMessagePost.argtypes = [CmMessage, String, POINTER(CmMessageHandler)]
    CmMessagePost.restype = CmMessageIterator

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 110
if _libs["libpycm.so"].has("CmMessagePrepareHandler", "cdecl"):
    CmMessagePrepareHandler = _libs["libpycm.so"].get("CmMessagePrepareHandler", "cdecl")
    CmMessagePrepareHandler.argtypes = [CmConnect]
    CmMessagePrepareHandler.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 111
if _libs["libpycm.so"].has("CmMessageInstallDefaultHandler", "cdecl"):
    CmMessageInstallDefaultHandler = _libs["libpycm.so"].get("CmMessageInstallDefaultHandler", "cdecl")
    CmMessageInstallDefaultHandler.argtypes = [POINTER(CmMessageHandler)]
    CmMessageInstallDefaultHandler.restype = CmMessageHandler

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 112
if _libs["libpycm.so"].has("CmMessageInstallHandler", "cdecl"):
    CmMessageInstallHandler = _libs["libpycm.so"].get("CmMessageInstallHandler", "cdecl")
    CmMessageInstallHandler.argtypes = [POINTER(CmMessageHandler), String]
    CmMessageInstallHandler.restype = CmMessageHandler

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 113
if _libs["libpycm.so"].has("CmMessageUninstallHandler", "cdecl"):
    CmMessageUninstallHandler = _libs["libpycm.so"].get("CmMessageUninstallHandler", "cdecl")
    CmMessageUninstallHandler.argtypes = [String]
    CmMessageUninstallHandler.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 114
if _libs["libpycm.so"].has("CmMessageAreYouThere", "cdecl"):
    CmMessageAreYouThere = _libs["libpycm.so"].get("CmMessageAreYouThere", "cdecl")
    CmMessageAreYouThere.argtypes = [String]
    CmMessageAreYouThere.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 115
if _libs["libpycm.so"].has("CmMessageCheck", "cdecl"):
    CmMessageCheck = _libs["libpycm.so"].get("CmMessageCheck", "cdecl")
    CmMessageCheck.argtypes = []
    CmMessageCheck.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 116
if _libs["libpycm.so"].has("CmMessageWait", "cdecl"):
    CmMessageWait = _libs["libpycm.so"].get("CmMessageWait", "cdecl")
    CmMessageWait.argtypes = []
    CmMessageWait.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 117
if _libs["libpycm.so"].has("CmMessageWaitWithTimeout", "cdecl"):
    CmMessageWaitWithTimeout = _libs["libpycm.so"].get("CmMessageWaitWithTimeout", "cdecl")
    CmMessageWaitWithTimeout.argtypes = [c_double]
    CmMessageWaitWithTimeout.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 118
if _libs["libpycm.so"].has("CmMessageServerCheck", "cdecl"):
    CmMessageServerCheck = _libs["libpycm.so"].get("CmMessageServerCheck", "cdecl")
    CmMessageServerCheck.argtypes = [String]
    CmMessageServerCheck.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 119
if _libs["libpycm.so"].has("CmMessageServerWait", "cdecl"):
    CmMessageServerWait = _libs["libpycm.so"].get("CmMessageServerWait", "cdecl")
    CmMessageServerWait.argtypes = [String]
    CmMessageServerWait.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 120
if _libs["libpycm.so"].has("CmMessageServerWaitWithTimeout", "cdecl"):
    CmMessageServerWaitWithTimeout = _libs["libpycm.so"].get("CmMessageServerWaitWithTimeout", "cdecl")
    CmMessageServerWaitWithTimeout.argtypes = [String, c_double]
    CmMessageServerWaitWithTimeout.restype = CmConnectCondition

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 121
if _libs["libpycm.so"].has("CmMessageTraceOn", "cdecl"):
    CmMessageTraceOn = _libs["libpycm.so"].get("CmMessageTraceOn", "cdecl")
    CmMessageTraceOn.argtypes = [c_int]
    CmMessageTraceOn.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 122
if _libs["libpycm.so"].has("CmMessageTraceOff", "cdecl"):
    CmMessageTraceOff = _libs["libpycm.so"].get("CmMessageTraceOff", "cdecl")
    CmMessageTraceOff.argtypes = []
    CmMessageTraceOff.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 123
if _libs["libpycm.so"].has("CmMessageGetItemType", "cdecl"):
    CmMessageGetItemType = _libs["libpycm.so"].get("CmMessageGetItemType", "cdecl")
    CmMessageGetItemType.argtypes = [CmMessage]
    CmMessageGetItemType.restype = CmMessageItemType

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 124
if _libs["libpycm.so"].has("CmMessagePutChar", "cdecl"):
    CmMessagePutChar = _libs["libpycm.so"].get("CmMessagePutChar", "cdecl")
    CmMessagePutChar.argtypes = [CmMessage, c_char]
    CmMessagePutChar.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 125
if _libs["libpycm.so"].has("CmMessageGetChar", "cdecl"):
    CmMessageGetChar = _libs["libpycm.so"].get("CmMessageGetChar", "cdecl")
    CmMessageGetChar.argtypes = [CmMessage]
    CmMessageGetChar.restype = c_char

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 126
if _libs["libpycm.so"].has("CmMessagePutShort", "cdecl"):
    CmMessagePutShort = _libs["libpycm.so"].get("CmMessagePutShort", "cdecl")
    CmMessagePutShort.argtypes = [CmMessage, c_short]
    CmMessagePutShort.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 127
if _libs["libpycm.so"].has("CmMessageGetShort", "cdecl"):
    CmMessageGetShort = _libs["libpycm.so"].get("CmMessageGetShort", "cdecl")
    CmMessageGetShort.argtypes = [CmMessage]
    CmMessageGetShort.restype = c_short

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 128
if _libs["libpycm.so"].has("CmMessagePutInt", "cdecl"):
    CmMessagePutInt = _libs["libpycm.so"].get("CmMessagePutInt", "cdecl")
    CmMessagePutInt.argtypes = [CmMessage, c_int]
    CmMessagePutInt.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 129
if _libs["libpycm.so"].has("CmMessageGetInt", "cdecl"):
    CmMessageGetInt = _libs["libpycm.so"].get("CmMessageGetInt", "cdecl")
    CmMessageGetInt.argtypes = [CmMessage]
    CmMessageGetInt.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 130
if _libs["libpycm.so"].has("CmMessagePutLong", "cdecl"):
    CmMessagePutLong = _libs["libpycm.so"].get("CmMessagePutLong", "cdecl")
    CmMessagePutLong.argtypes = [CmMessage, c_long]
    CmMessagePutLong.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 131
if _libs["libpycm.so"].has("CmMessageGetLong", "cdecl"):
    CmMessageGetLong = _libs["libpycm.so"].get("CmMessageGetLong", "cdecl")
    CmMessageGetLong.argtypes = [CmMessage]
    CmMessageGetLong.restype = c_long

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 132
if _libs["libpycm.so"].has("CmMessagePutFloat", "cdecl"):
    CmMessagePutFloat = _libs["libpycm.so"].get("CmMessagePutFloat", "cdecl")
    CmMessagePutFloat.argtypes = [CmMessage, c_float]
    CmMessagePutFloat.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 133
if _libs["libpycm.so"].has("CmMessageGetFloat", "cdecl"):
    CmMessageGetFloat = _libs["libpycm.so"].get("CmMessageGetFloat", "cdecl")
    CmMessageGetFloat.argtypes = [CmMessage]
    CmMessageGetFloat.restype = c_float

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 134
if _libs["libpycm.so"].has("CmMessagePutDouble", "cdecl"):
    CmMessagePutDouble = _libs["libpycm.so"].get("CmMessagePutDouble", "cdecl")
    CmMessagePutDouble.argtypes = [CmMessage, c_double]
    CmMessagePutDouble.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 135
if _libs["libpycm.so"].has("CmMessageGetDouble", "cdecl"):
    CmMessageGetDouble = _libs["libpycm.so"].get("CmMessageGetDouble", "cdecl")
    CmMessageGetDouble.argtypes = [CmMessage]
    CmMessageGetDouble.restype = c_double

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 136
if _libs["libpycm.so"].has("CmMessagePutArray", "cdecl"):
    CmMessagePutArray = _libs["libpycm.so"].get("CmMessagePutArray", "cdecl")
    CmMessagePutArray.argtypes = [CmMessage, CmMessageArrayType, c_int, POINTER(None)]
    CmMessagePutArray.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 137
if _libs["libpycm.so"].has("CmMessagePutExtArray", "cdecl"):
    CmMessagePutExtArray = _libs["libpycm.so"].get("CmMessagePutExtArray", "cdecl")
    CmMessagePutExtArray.argtypes = [CmMessage, CmMessageArrayType, c_int, POINTER(None)]
    CmMessagePutExtArray.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 138
if _libs["libpycm.so"].has("CmMessageGetArray", "cdecl"):
    CmMessageGetArray = _libs["libpycm.so"].get("CmMessageGetArray", "cdecl")
    CmMessageGetArray.argtypes = [CmMessage, POINTER(CmMessageArrayType), POINTER(c_int)]
    CmMessageGetArray.restype = POINTER(c_ubyte)
    CmMessageGetArray.errcheck = lambda v,*a : cast(v, c_void_p)

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 139
if _libs["libpycm.so"].has("CmMessagePutText", "cdecl"):
    CmMessagePutText = _libs["libpycm.so"].get("CmMessagePutText", "cdecl")
    CmMessagePutText.argtypes = [CmMessage, String]
    CmMessagePutText.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 140
if _libs["libpycm.so"].has("CmMessageGetText", "cdecl"):
    CmMessageGetText = _libs["libpycm.so"].get("CmMessageGetText", "cdecl")
    CmMessageGetText.argtypes = [CmMessage]
    if sizeof(c_int) == sizeof(c_void_p):
        CmMessageGetText.restype = ReturnString
    else:
        CmMessageGetText.restype = String
        CmMessageGetText.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 141
if _libs["libpycm.so"].has("CmMessagePutBytes", "cdecl"):
    CmMessagePutBytes = _libs["libpycm.so"].get("CmMessagePutBytes", "cdecl")
    CmMessagePutBytes.argtypes = [CmMessage, String, c_int]
    CmMessagePutBytes.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 142
if _libs["libpycm.so"].has("CmMessageGetBytes", "cdecl"):
    CmMessageGetBytes = _libs["libpycm.so"].get("CmMessageGetBytes", "cdecl")
    CmMessageGetBytes.argtypes = [CmMessage, POINTER(c_int)]
    if sizeof(c_int) == sizeof(c_void_p):
        CmMessageGetBytes.restype = ReturnString
    else:
        CmMessageGetBytes.restype = String
        CmMessageGetBytes.errcheck = ReturnString

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 143
if _libs["libpycm.so"].has("CmMessageIteratorDelete", "cdecl"):
    CmMessageIteratorDelete = _libs["libpycm.so"].get("CmMessageIteratorDelete", "cdecl")
    CmMessageIteratorDelete.argtypes = [CmMessageIterator]
    CmMessageIteratorDelete.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 144
if _libs["libpycm.so"].has("CmMessageIteratorStop", "cdecl"):
    CmMessageIteratorStop = _libs["libpycm.so"].get("CmMessageIteratorStop", "cdecl")
    CmMessageIteratorStop.argtypes = [CmMessageIterator]
    CmMessageIteratorStop.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 145
if _libs["libpycm.so"].has("CmMessageIteratorCallHandler", "cdecl"):
    CmMessageIteratorCallHandler = _libs["libpycm.so"].get("CmMessageIteratorCallHandler", "cdecl")
    CmMessageIteratorCallHandler.argtypes = [CmMessageIterator]
    CmMessageIteratorCallHandler.restype = CmMessageStatus

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 146
if _libs["libpycm.so"].has("CmMessageIteratorFinished", "cdecl"):
    CmMessageIteratorFinished = _libs["libpycm.so"].get("CmMessageIteratorFinished", "cdecl")
    CmMessageIteratorFinished.argtypes = [CmMessageIterator]
    CmMessageIteratorFinished.restype = c_int

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 147
if _libs["libpycm.so"].has("CmMessageIteratorForth", "cdecl"):
    CmMessageIteratorForth = _libs["libpycm.so"].get("CmMessageIteratorForth", "cdecl")
    CmMessageIteratorForth.argtypes = [CmMessageIterator]
    CmMessageIteratorForth.restype = None

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 148
if _libs["libpycm.so"].has("CmMessageCallHandler", "cdecl"):
    CmMessageCallHandler = _libs["libpycm.so"].get("CmMessageCallHandler", "cdecl")
    CmMessageCallHandler.argtypes = [CmMessage]
    CmMessageCallHandler.restype = CmConnectStatus

# /virgoDev/PyCm/v7r4/src/Handlers.h: 25
if _libs["libpycm.so"].has("H_FbGetAllSmsData", "cdecl"):
    H_FbGetAllSmsData = _libs["libpycm.so"].get("H_FbGetAllSmsData", "cdecl")
    H_FbGetAllSmsData.argtypes = [CmMessage, String, String]
    H_FbGetAllSmsData.restype = CmMessageStatus

# /virgoDev/PyCm/v7r4/src/Handlers.h: 26
if _libs["libpycm.so"].has("WriteSmsString", "cdecl"):
    WriteSmsString = _libs["libpycm.so"].get("WriteSmsString", "cdecl")
    WriteSmsString.argtypes = [String]
    WriteSmsString.restype = c_int

__const = c_int# <command-line>: 4

# <command-line>: 7
try:
    CTYPESGEN = 1
except:
    pass

# /usr/include/stdc-predef.h: 19
try:
    _STDC_PREDEF_H = 1
except:
    pass

# /usr/include/stdc-predef.h: 30
try:
    __STDC_IEC_559__ = 1
except:
    pass

# /usr/include/stdc-predef.h: 31
try:
    __STDC_IEC_559_COMPLEX__ = 1
except:
    pass

# /usr/include/stdc-predef.h: 35
try:
    __STDC_ISO_10646__ = 201103.0
except:
    pass

# /usr/include/stdc-predef.h: 38
try:
    __STDC_NO_THREADS__ = 1
except:
    pass

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 54
def GCReferenceAssignIn(loc, container, object):
    return (GCReferenceSet (cast(pointer(loc), POINTER(POINTER(None))), container, object))

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 59
def GCReferenceAssign(loc, object):
    return (GCReferenceSet (cast(pointer(loc), POINTER(POINTER(None))), NULL, object))

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 64
def GCReferenceClear(loc):
    return (GCReferenceSet (cast(pointer(loc), POINTER(POINTER(None))), NULL, NULL))

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 101
try:
    CmConnectInstallDisconnectionHandler = CmConnectInstallDHandler
except:
    pass

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 102
try:
    CmConnectInstallConnectionHandler = CmConnectInstallCHandler
except:
    pass

# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 103
try:
    CmConnectStartupAsMultipleServer = CmConnectStartupAsMS
except:
    pass

_CmMessageRec = struct__CmMessageRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 38

_CmMessageIteratorRec = struct__CmMessageIteratorRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmMessage.h: 39

_GCReferenceRec = struct__GCReferenceRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 36

_GCClassRec = struct__GCClassRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 37

_GCObjectRec = struct__GCObjectRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/GC.h: 38

_CArrayRec = struct__CArrayRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 38

_CStackRec = struct__CStackRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 39

_CQueueRec = struct__CQueueRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 40

_CLListRec = struct__CLListRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 41

_CHasherRec = struct__CHasherRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 42

_CIteratorRec = struct__CIteratorRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CSet.h: 43

_CmConnectRec = struct__CmConnectRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 40

_CmConnectIteratorRec = struct__CmConnectIteratorRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 41

_CmNameServerInfosRec = struct__CmNameServerInfosRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 73

_CmConnectStatisticsRec = struct__CmConnectStatisticsRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmConnect.h: 84

_CvtRec = struct__CvtRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/Cvt.h: 38

_CmTransactionRec = struct__CmTransactionRec# /virgoApp/Cm/v9r0/Linux-x86_64-CL7/include/cm/CmTransaction.h: 4

# No inserted files

# No prefix-stripping

